@@ -8,18 +8,20 @@ import time
 import getopt
 import sys
 import importlib
+import logging
 
 # Modules:
 from calcure.calendars import Calendar
 from calcure.configuration import cf
 from calcure.weather import Weather
-from calcure.repository import FileRepository
 from calcure.importers import Importer
 from calcure.dialogues import clear_line
 from calcure.screen import Screen
+from calcure.savers import TaskSaverCSV, EventSaverCSV
+from calcure.colors import initialize_colors
+from calcure.loaders import TaskLoaderCSV, TaskLoaderICS, EventLoaderCSV, EventLoaderICS, HolidayLoader, BirthdayLoader
 from calcure.data import *
 from calcure.controls import *
-from calcure.helpers import initialize_colors
 
 
 # Language:
@@ -39,10 +41,10 @@ else:
     from calcure.translations.en import *
 
 
-__version__ = "2.7.3"
+__version__ = "2.7.5"
 
 
-def read_items_from_user_arguments(screen, user_tasks, user_events, file_repository):
+def read_items_from_user_arguments(screen, user_tasks, user_events, task_saver_csv, event_saver_csv):
     """Read --task and --event flags from user arguments to create new tasks or events"""
     try:
         opts, _ = getopt.getopt(sys.argv[1:], "pjhvi", ["folder=", "config=", "task=", "event="])
@@ -51,7 +53,7 @@ def read_items_from_user_arguments(screen, user_tasks, user_events, file_reposit
                 name = arg
                 user_tasks.add_item(Task(len(user_tasks.items), name, Status.NORMAL, Timer([]), False))
                 screen.state = AppState.EXIT
-                file_repository.save_tasks_to_csv()
+                task_saver_csv.save()
             if opt in '--event':
                 year = int(arg.split("-")[0])
                 month = int(arg.split("-")[1])
@@ -61,8 +63,7 @@ def read_items_from_user_arguments(screen, user_tasks, user_events, file_reposit
                 user_events.add_item(UserEvent(event_id, year, month, day, name,
                                         1, Frequency.ONCE, Status.NORMAL, False))
                 screen.state = AppState.EXIT
-                file_repository.save_events_to_csv()
-
+                event_saver_csv.save()
     except (getopt.GetoptError, ValueError):
         pass
 
@@ -900,25 +901,38 @@ class HelpScreenView(View):
         self.display_line(d_y + 5, d_x, MSG_SITE, Color.TITLE)
 
 
-def main(stdscr) -> None:
-    """Main function that runs and switches screens"""
+def main(stdscr):
+    """Main function that loads the data, runs and switches screens"""
 
-    # Load the data:
+    # Load weather:
     weather = Weather(cf.WEATHER_CITY)
     if cf.SHOW_WEATHER:
-        print(MSG_WEATHER)
+        sys.stdout.write(f"\r{MSG_WEATHER}")
         weather.load_from_wttr()
-    screen = Screen(stdscr, cf)
-    file_repository = FileRepository(cf)
-    user_events = file_repository.load_events_from_csv()
-    user_tasks = file_repository.load_tasks_from_csv()
-    user_ics_tasks = file_repository.load_tasks_from_ics()
-    user_ics_events = file_repository.load_events_from_ics()
-    holidays = file_repository.load_holidays()
-    birthdays = file_repository.load_birthdays_from_abook()
+
+    # Initialise loaders:
+    event_loader_csv = EventLoaderCSV(cf)
+    task_loader_csv = TaskLoaderCSV(cf)
+    event_loader_ics = EventLoaderICS(cf)
+    task_loader_ics = TaskLoaderICS(cf)
+    birthday_loader = BirthdayLoader(cf)
+    holiday_loader = HolidayLoader(cf)
+
+    # Load the data:
+    user_events = event_loader_csv.load()
+    user_tasks = task_loader_csv.load()
+    user_ics_events = event_loader_ics.load()
+    user_ics_tasks = task_loader_ics.load()
+    holidays = holiday_loader.load()
+    birthdays = birthday_loader.load()
+
+    # Initialise savers and importers:
+    event_saver_csv = EventSaverCSV(user_events, cf)
+    task_saver_csv = TaskSaverCSV(user_tasks, cf)
     importer = Importer(user_tasks, user_events, cf)
 
-    read_items_from_user_arguments(screen, user_tasks, user_events, file_repository)
+    screen = Screen(stdscr, cf)
+    read_items_from_user_arguments(screen, user_tasks, user_events, task_saver_csv, event_saver_csv)
 
     # Initialise terminal screen:
     stdscr = curses.initscr()
@@ -952,8 +966,6 @@ def main(stdscr) -> None:
             app_view.fill_background()
         screen.active_pane = False
 
-        # CALENDARS
-
         # Monthly (active) screen:
         if screen.state == AppState.CALENDAR and screen.calendar_state == CalState.MONTHLY:
             if screen.split and not screen.selection_mode:
@@ -978,8 +990,6 @@ def main(stdscr) -> None:
             footer_view.render()
             control_daily_screen(stdscr, user_events, screen, importer)
 
-        # JOURNAL
-
         # Journal (active) screen:
         elif screen.state == AppState.JOURNAL:
             if screen.split and not screen.selection_mode:
@@ -1006,10 +1016,10 @@ def main(stdscr) -> None:
 
         # If something has been changed, save the data:
         if user_events.changed:
-            file_repository.save_events_to_csv()
+            event_saver_csv.save()
             screen.refresh_now = True
         if user_tasks.changed:
-            file_repository.save_tasks_to_csv()
+            task_saver_csv.save()
             screen.refresh_now = True
 
     # Cleaning up before quitting:
