@@ -5,6 +5,7 @@ import pathlib
 import configparser
 import sys
 import getopt
+import logging
 
 from calcure.data import AppState
 
@@ -22,13 +23,11 @@ class Config:
 
     def create_config_file(self):
         """Create config.ini file if it does not exist"""
+
         if os.path.exists(self.config_file):
             self.is_first_run = False
             return
 
-        if not os.path.exists(self.config_folder):
-            os.makedirs(self.config_folder)
-
         conf = configparser.ConfigParser()
         conf["Parameters"] = {
                 "folder_with_datafiles":     str(self.config_folder),
@@ -222,11 +221,11 @@ class Config:
             self.ONE_TIMER_AT_A_TIME   = conf.getboolean("Parameters", "one_timer_at_a_time", fallback=False)
 
             # ICS files:
-            self.ICS_EVENT_FILES = conf.get("Parameters", "ics_event_files", fallback=None)
+            self.ICS_EVENT_FILES = conf.get("Parameters", "ics_event_files", fallback=None, raw=True)
             if self.ICS_EVENT_FILES is not None:
                 self.ICS_EVENT_FILES = [str(i) for i in self.ICS_EVENT_FILES.split(",")]
 
-            self.ICS_TASK_FILES = conf.get("Parameters", "ics_task_files", fallback=None)
+            self.ICS_TASK_FILES = conf.get("Parameters", "ics_task_files", fallback=None, raw=True)
             if self.ICS_TASK_FILES is not None:
                 self.ICS_TASK_FILES = [str(i) for i in self.ICS_TASK_FILES.split(",")]
 
@@ -295,10 +294,9 @@ class Config:
             self.TASKS_FILE = self.data_folder + "/tasks.csv"
 
         except Exception:
-            ERR_FILE1 = "Looks like there is a problem in your config.ini file. Perhaps you edited it and entered a wrong line."
+            ERR_FILE1 = "Looks like there is a problem in your config.ini file. Perhaps you edited it and entered a wrong line. "
             ERR_FILE2 = "Try removing your config.ini file and run the program again, it will create a fresh working config file."
-            print(ERR_FILE1)
-            print(ERR_FILE2)
+            logging.error(ERR_FILE1 + ERR_FILE2)
             exit()
 
     def read_config_file_from_user_arguments(self):
@@ -334,15 +332,28 @@ class Config:
                     self.DEFAULT_VIEW = AppState.HELP
                 elif opt in ('-v'):
                     self.DEFAULT_VIEW = AppState.EXIT
-                    print ('Calcure - version 2.5')
+                    print ('Calcure - version 2.8')
                 elif opt in ('-i'):
                     self.USE_PERSIAN_CALENDAR = True
         except getopt.GetoptError:
+            logging.error("Invalid user arguments")
             pass
 
 
-# Read config file:
 cf = Config()
+
+# Create config folder:
+if not os.path.exists(cf.config_folder):
+    os.makedirs(cf.config_folder)
+
+# Start logging:
+logging.basicConfig(level=logging.INFO,
+                    format="[%(levelname)s] %(message)s",
+                    encoding='utf-8',
+                    handlers=[logging.FileHandler(f"{cf.config_folder}/info.log", 'w'),
+                              logging.StreamHandler()],)
+
+# Read config file:
 cf.create_config_file()
 cf.read_config_file_from_user_arguments()
 cf.read_config_file()
